/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    Timon Veenstra <monezz@gmail.com> - initial API and implementation and/or initial documentation
 */
package eu.agrosense.client.env;

import java.lang.reflect.Method;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.openide.LifecycleManager;

/**
 *
 * To enable environment checking for your netbeans platform application, 
 * add following to your application.conf:
 * 
 * -J-Dnetbeans.mainclass=eu.agrosense.client.env.CustomStartup
 * 
 * result will be something like:
 * 
 * default_options="--branding ${branding.token} -J-Xms512m -J-Xmx512m -J-XX:PermSize=32m -J-XX:MaxPermSize=128m -J-Xverify:none -J-Dnetbeans.mainclass=eu.agrosense.client.env.CustomStartup"
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class CustomStartup {

    private static final String NB_MAIN_CLASS = "org.netbeans.core.startup.Main";
    private static final Logger LOGGER = Logger.getLogger(CustomStartup.class.getName());

    public static void main(String[] args) throws Exception {
        // do whatever you need here (e.g. show a custom login form)
       boolean envValid = false;
        String versionString = System.getProperty("java.version");
        LOGGER.log(Level.INFO, "Java version:{0}", versionString);
        String[] versionComponents = versionString.split("\\.");
        assert versionComponents.length == 3 : "Version should contain 3 components separated by . " + versionString + "actually contained " + versionComponents.length;
        if (Integer.valueOf(versionComponents[0]).intValue() >= 1
                && Integer.valueOf(versionComponents[1]).intValue() >= 7) {
            envValid = true;
            LOGGER.log(Level.INFO, "Java version validated");
        }else{
            LOGGER.log(Level.WARNING, "Invalid java version, showing dialog");
        }

        if (!envValid) {
//            try {
//                java.awt.EventQueue.invokeAndWait(new Runnable() {
//                    public void run() {
                        InvalidJavaVersionDialog dialog = new InvalidJavaVersionDialog(new javax.swing.JFrame(), true);
                        dialog.addWindowListener(new java.awt.event.WindowAdapter() {
                            @Override
                            public void windowClosing(java.awt.event.WindowEvent e) {
                                System.exit(0);
                            }
                        });
                        dialog.setVisible(true);
//                    }
//                });
//            } catch (InterruptedException ex) {
//                Exceptions.printStackTrace(ex);
//            } catch (InvocationTargetException ex) {
//                Exceptions.printStackTrace(ex);
//            }
            LifecycleManager.getDefault().exit();
        }


        // once you're done with that, hand control back to NetBeans
        ClassLoader classloader = Thread.currentThread().getContextClassLoader();
        Class<?> mainClass = Class.forName(NB_MAIN_CLASS, true, classloader);

        Object mainObject = mainClass.newInstance();
        Method mainMethod = mainClass.getDeclaredMethod("main", new Class[]{String[].class});
        mainMethod.invoke(mainObject, (Object) args);
    }
}
